options(BioC_mirror = "http://mirrors.ustc.edu.cn/bioc/")
source('http://bioconductor.org/biocLite.R')
#biocLite('KEGG.db')
#biocLite("affyPLM")
#biocLite("affycoretools")
#install.packages("cluster")
#biocLite("preprocessCore")
#biocLite("genefilter")
#biocLite("RSQLite")
#biocLite("Category")
#biocLite("GOstats")
#install.packages("Matrix")

library(preprocessCore)
library(affy)
library(genefilter)
library(RSQLite)

library(simpleaffy)
library(gcrma)
library(affyPLM)
library(RColorBrewer)

library(graph)
library(affycoretools)
library(limma)
library(tcltk)
library(annotate)
library(XML)
library(IRanges)
library(org.Hs.eg.db)
library(DBI)

library(pheatmap)
library(GOstats)
library(base)
library(GeneAnswers)
library(GO.db)
getwd()
#Read the data from the computer
filters <- matrix(c("CEL file", ".[Cc][Ee][Ll]", "All", ".*"), ncol = 2, byrow = T)
cel.files <-tk_choose.files(caption = "Select CELs", multi = TRUE,filters = filters, index = 1)
data.raw <- ReadAffy(filenames = cel.files)
data.raw            #读取第一次质量控制筛选出的71例合格样本进行第二次质量控制

#Quality Control report                                              
Data.qc <- qc(data.raw)    #获取质量分析报告                  
plot(Data.qc)    #图形化显示报告

#the original、weights、residual、residual.sign figures of Microarray data
Pset <- fitPLM(data.raw)    #对数据集做回归计算，结果是一个“PLMset”类型的对象
image(data.raw[,1])           #画第一个芯片数据的原始图        
image(Pset,type="weights",which=1,main="Weights")           #根据计算结果画权重图    
image(Pset,type="resids",which=1,main="Residuals")          #根据计算结果画残差图    
image(Pset,type="sign.resids",which=1,main="Residuals.sign")        #根据计算结果画残差符号图

#draw relative log expression boxplot and normalized unscaled standard errors boxplot.
colors <- brewer.pal(12,"Set3")                                         #载入一组颜色
Mbox(Pset,ylim=c(-1,1),col=colors,main="RLE",las=3)    #绘制RLE（相对对数表达）箱线图     
boxplot(Pset,ylim=c(0.95,1.22),col=colors,main="NUSE",las=3)       #绘制NUSE（相对标准差）箱线图，较RLE精确
#draw RNA degradation figure
data.deg <- AffyRNAdeg(data.raw)  #获取降解数据
colors <- brewer.pal(12,"Set3")        #载入一组颜色
plotAffyRNAdeg(data.deg,col=colors)  #绘制RNA降解图
legend("topleft",rownames(pData(data.raw)),col=colors,lwd=1,inset=0.05,cex=0.5)   
#在RNA降解图的左上部位加注图注

#draw the figures of clustering analysis 
dgcrma <- gcrma(data.raw)  #使用gcrma算法来预处理数据
eset <- exprs(dgcrma)      #提取基因表达矩阵
pearson_cor <- cor(eset)      #计算样品两两之间的pearson相关系数
dist.lower <- as.dist(1 - pearson_cor)  #得到pearson距离的下三角矩阵
hc <- hclust(dist.lower,"ave")           #聚类分析
plot(hc)             #根据聚类结果画图

# Standardized treatment
dmas5 <- mas5(data.raw)                        
drma <- rma(data.raw)                                 
dgcrma <- gcrma(data.raw)
#分别用MAS5，rma，gcrma算法来预处理数据，需进行算法比较，进而确定哪种算法最合适

# draw histogram 
colors <- brewer.pal(12,"Set3")
hist(data.raw,main="original",col=colors)             
legend("topright",rownames(pData(data.raw)),col=colors,lwd=1,inset=0.05,cex=0.5,ncol=3)
hist(dmas5,main="MAS5.0",xlim=c(-150,2^10),col=colors)
hist(drma,main="RMA",col=colors)
hist(dgcrma,main="gcRMA",col=colors)       #绘制各个算法预处理前后的直方图

# draw boxplot
boxplot(data.raw,col=colors,las=3,ylim=c(0,20),main="original")            
boxplot(dmas5,col=colors,las=3,ylim=c(0,1000),main="MAS5.0")
boxplot(drma,col=colors,las=3,ylim=c(0,20),main="RMA")
boxplot(dgcrma,col=colors,las=3,ylim=c(0,20),main="gcRMA")  
#绘制各个算法预处理前后的箱线图

# draw MAplot
MAplot(data.raw[,1:4],pairs=TRUE,plot.method="smoothScatter",cex=0.8,main="originalMAplot")
MAplot(dgcrma[,1:4],pairs=TRUE,plot.method="smoothScatter",cex=0.8,main="gcRMAMAplot")  #绘制gcrma算法预处理前后的MA图

# 差异表达基因的筛选%
s<-sampleNames(data.raw)    #把71例样本名称排成一竖列，列名为s
as.character(s)                #查看此列样本名称
data.frame(s)                    #生成一个矩阵形式的列表
a<-data.frame(s)            #将此列表赋值为a
View(a)

getwd()     #查看默认路径
disease<-read.csv("C:\\Users\\Administrator\\Desktop\\生物医药文本挖掘和知识发现\\presentation\\data_new_new.csv",header = T) 
#将表格另存为.csv格式的文件，存在默认路径下，将表格中的数据读入R中。
disease<-factor(disease[,"Disease"])         #提取实验条件信息
design<-model.matrix(~-1+disease)     #构建实验设计矩阵
View(design)
colnames(design) <- c("s1", "s2")               
#s1列样本若是转移癌为0，原发癌癌为1；s2列样本若是转移癌为1，若是原发癌为0。
contrast.matrix <- makeContrasts(s1-s2, levels=design)    
#构建对比模型，比较两个实验条件下表达数据
fit <- lmFit(eset[, 1 : 30], design)                              #线性模型拟合
fit1<- contrasts.fit(fit, contrast.matrix)         #根据对比模型进行差值运算
fit2 <- eBayes(fit1)         #贝叶斯检验
results<-decideTests(fit2, method="global", adjust.method="BH",p.value=0.01,lfc=1.5) 
summary(results)
View(results)
dif<- topTable(fit2, coef=1, number=10000, adjust.method="BH", sort.by="B", resort.by="M")     #生成所有基因的检验结果报表
dif<-dif[dif[,"P.Value"]<0.001,]                   
#根据P-Value对结果进行筛选，得到全部差异表达基因，本实验得到93个差异表达基因。
View(dif)

affydb<-annPkgName(data.raw@annotation,type="db")   #获得基因芯片注释包名称
affydb                                                                    #GSE2603的样本的affydb为hgu133a
library(affydb,character.only=TRUE)                    #设定character.only
dif$symbols<-getSYMBOL(rownames(dif),affydb)       
#根据每个探针组的ID获取对应的基因Gene Symbol，并作为一个新的列，加到数据框dif最后
head(dif)            #显示结果前六行
dif$EntrezID<-getEG(rownames(dif),affydb)          
#根据每个探针组的ID获取对应的基因Entrez ID,同样加到数据框dif最后
head(dif)
write.csv(dif, "C:\\Users\\Administrator\\Desktop\\生物医药文本挖掘和知识发现\\presentation\\results.go.0610.csv")              
#生成dif结果的excel表格文件，文件名为results.go.0610

#GO的富集分析及可视化
entrezUniverse<-unique(unlist(mget(rownames(eset),hgu133aENTREZID))) 
#提取HG-U133 A芯片中所有探针组对应的EntrezID，注意保证uniq
entrezSelected<-unique(dif[!is.na(dif$EntrezID),"EntrezID"])    
#提取所有差异表达基因及其对应的EntrezID，注意保证uniq
params <- new("GOHyperGParams", geneIds=entrezSelected, universeGeneIds=entrezUniverse, annotation=affydb, ontology="BP", pvalueCutoff=0.0026, conditional=FALSE, testDirection="over")           
#设置GO富集分析的所有参数
hgOver<-hyperGTest(params)                                           
#对所有的GOterm根据params参数做超几何实验
bp<-summary(hgOver)                                                    
#生成所有GOterm的检验结果报表
head(bp)

htmlReport(hgOver,file="ALL_go.html")
#htmlReport(hgOver,dir=getwd(),file="ALL_go.html")                   
#同时生成所有GOterm的检验结果文件，每个GOterm都有指向官方网站的链接，可以获得其详细信息。

#KEGG通路富集分析及可视化
humanGeneInput<-dif[,c("EntrezID","logFC","P.Value")]                 
#选取dif中的三列信息构成新的矩阵，第一列必须是EntrezID          
humanExpr<-eset[match(rownames(dif),rownames(eset)),]                 
#获得humanGeneInput中基因的表达值
humanExpr<-cbind(humanGeneInput[,"EntrezID"],humanExpr)            
#前两个数据做合并，第一列必须是EntrezID 
humanGeneInput<-humanGeneInput[!is.na(humanGeneInput[,1]),]           
#去除NA数据
y<-geneAnswersBuilder(humanGeneInput,"org.Hs.eg.db",categoryType="KEGG",testType="hyperG",pvalueT=0.01,OnProfile=humanExpr,verbose=FALSE)
getEnrichmentInfo(y)[1,]
#KEGG通路的超几何检验
#绘制显著富集的KEGG通路的关系图和热图
selected<-eset[rownames(dif),] #从基因表达矩阵中选取差异表达基因对应的数据
rownames(selected)<-dif$symbols   
#将selected矩阵每行的名称由探针组ID转换为对应的基因symbol
pheatmap(selected[1:20,],color=colorRampPalette(c("green","black","red"))(100),fontsize_row=4,scale="row",border_color=NA)           #画前20个基因的热图
#biocLite("Rgraphviz")
library(Rgraphviz)
ghandle<-goDag(hgOver)
subGHandle<-subGraph(snodes=as.character(summary(hgOver)[,1]),graph=ghandle)
plot(subGHandle)
yy<-geneAnswersReadable(y,verbose=FALSE)
geneAnswersConceptNet(yy,colorValueColumn="logFC",centroidSize="pvalue",output="interactive")
#yyy<-geneAnswersHeatmap(y)

















